@@ -15,9 +15,12 @@ var conf=js_vars["teedoc-plugin-ad-hint"];
             $("#new_feature_content").slideUp();
         });
         if(conf.show_times > 0){ // only show some times and disapear
-            var date = new Date(conf.date).getTime()/1000;
-            var times = show_time(date_ts = date);
-            if(new Date().getTime()/1000 < date){ // always show if not reach date
+            var date = null;
+            if(conf.date){
+                date = new Date(conf.date).getTime()/1000;
+            }
+            var times = show_time(-1, date);
+            if(date && (new Date().getTime()/1000 < date)){ // always show if not reach date
                 times = -1;
             }
             if(times == 0){
@@ -32,7 +35,7 @@ var conf=js_vars["teedoc-plugin-ad-hint"];
     }
 })();
 
-function show_time(times = -1, date_ts=0){
+function show_time(times = -1, date_ts=null){
     if(times < 0){
         var s = localStorage.getItem("hint_show_times");
         if(!s){
@@ -40,7 +43,7 @@ function show_time(times = -1, date_ts=0){
         }else{
             var o = JSON.parse(s);
             var now = new Date().getTime()/1000;
-            if((now - o.ts > conf.show_after_s) || !("update" in o) || (o.update < date_ts)){ // timeout or have new info
+            if((now - o.ts > conf.show_after_s) || !("update" in o) || (date_ts && o.update && (o.update < date_ts)) || (date_ts && !o.update) ){ // timeout or have new info
                 times = -1;
             }else{
                 times = o.times;
